@@ -319,7 +319,7 @@ class TestStripFirstParameter(support.CommonTestBase, support.TestCase):
         original_function_maker = self._make_function_maker(function)
         function_maker = self._make_function_maker(function)
         self._call_sut(function_maker)
-        for attribute_name in ('args', 'varargs', 'keywords', 'signature',
+        for attribute_name in ('args', 'varargs', 'varkw', 'signature',
           'defaults'):
             original_attribute = getattr(original_function_maker,
               attribute_name)
@@ -352,10 +352,10 @@ class TestStripFirstParameter(support.CommonTestBase, support.TestCase):
 
     def test_it_should_preserve_keyword_arguments(self):
         function_maker = self._make_function_maker(lambda first, **kwargs: 42)
-        self.assert_equal(function_maker.keywords, 'kwargs')
+        self.assert_equal(function_maker.varkw, 'kwargs')
         self.assert_equal(function_maker.signature, 'first, **kwargs')
         self._call_sut(function_maker)
-        self.assert_equal(function_maker.keywords, 'kwargs')
+        self.assert_equal(function_maker.varkw, 'kwargs')
         self.assert_equal(function_maker.signature, '**kwargs')
 
     def test_it_should_preserve_defaults(self):
