@@ -222,7 +222,7 @@ def _strip_first_parameter(function_maker):
         # E.g. def func(**kwargs):
         return
     if len(function_maker.args) == 1 and not function_maker.varargs and not \
-      function_maker.keywords:
+      function_maker.varkw:
         # E.g. def func(first):
         function_maker.signature = ''
         function_maker.args = []
@@ -309,7 +309,9 @@ def _function_wrapper_from_template(function, template,
         raise TypeError('First argument must be a function.')
     wrapper_maker = decorator.FunctionMaker(function)
     if strip_first_parameter:
+        ## pylint: disable=E1101
         if not wrapper_maker.args and not wrapper_maker.varargs:
+            ## pylint: enable=E1101
             # E.g. def func():
             # E.g. def func(**kwargs):
             raise ValueError('Function must accept at least one positional '
